WNJMain class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • WNJMain
Implemented types

Constructors

WNJMain()

Properties

appAo ↔ dynamic
getter/setter pair
appImage → RxInt
final
appList ↔ dynamic
getter/setter pair
appName ↔ dynamic
getter/setter pair
appsflyerId ↔ dynamic
getter/setter pair
appVersion ↔ dynamic
getter/setter pair
callbackMessage → RxInt
final
cameraKey → RxString
final
cameraPermission ↔ dynamic
getter/setter pair
canRegister_of → RxList<String>
final
canTurn ↔ dynamic
getter/setter pair
channel ↔ dynamic
getter/setter pair
completerImage → RxInt
final
configMain → RxInt
final
deviceToken ↔ dynamic
getter/setter pair
deviceVersion ↔ dynamic
getter/setter pair
downloadLoaded → RxString
final
downloadPermission → RxBool
final
hasExecuted → RxString
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
heightController → RxString
final
homePort → RxString
final
idfaString ↔ dynamic
getter/setter pair
infoName → RxInt
final
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
keyPage → RxString
final
listeners int
no setterinherited
loadMap ↔ dynamic
getter/setter pair
locationPermission ↔ dynamic
getter/setter pair
mainBuild → RxString
final
microphonePermission ↔ dynamic
getter/setter pair
micStyle → RxString
final
notificationPermission ↔ dynamic
getter/setter pair
nu ↔ dynamic
getter/setter pair
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
photoPermission ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeImage → RxInt
final
spKey ↔ dynamic
getter/setter pair
stateDir → RxString
final
stringPending → RxString
final
systemVersion ↔ dynamic
getter/setter pair
trackingPermission ↔ dynamic
getter/setter pair
webpagePending → RxString
final
webpageStatus → RxString
final

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getAppInfo() → dynamic
getLoadMap() Future<String>
getSpkey() Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
saveChannel(String channel) → dynamic
saveDeviceToken(String token) → dynamic
saveLoadMapJson(String value) → dynamic
saveSpkey(String spKey) → dynamic
setAppsflyerId(String id) → dynamic
setCameraPermission(int value) → dynamic
setCanTurn(bool value) → dynamic
setIdfaString(String value, bool isAuthorized) → dynamic
setLocationPermission(int value) → dynamic
setMicrophonePermission(int value) → dynamic
setNotificationPermission(int value) → dynamic
setPhotoPermission(int value) → dynamic
setTrackingPermission(int value) → dynamic
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

to WNJMain
no setter