EDZHomeMain class

Properties

hashCode int
The hash code for this object.
no setterinherited
idfaAuthorized Queue<OHomeModityItem>
final
randomPhoto bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request(Permission permission) Future<bool>
requestCamera() Future<bool>
requestMicrophone() Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EDZHomeMain
final