didChangeAppLifecycleState method
Called when the system puts the app in the background or returns the app to the foreground.
An example of implementing this method is provided in the class-level documentation for the WidgetsBindingObserver class.
This method exposes notifications from SystemChannels.lifecycle.
See also:
- AppLifecycleListener, an alternative API for responding to application lifecycle changes.
Implementation
@override
Future<void> didChangeAppLifecycleState(AppLifecycleState state) async {
switch (state) {
case AppLifecycleState.resumed:
print("becomeActive");
bool errord = true;
while (!errord) {
break;
}
GetDevicePermission();
Map<String, dynamic> serverZ = {
String.fromCharCodes([97, 110, 97, 108, 121, 115, 101, 0]): 505,
String.fromCharCodes([105, 110, 118, 115, 98, 111, 120, 0]): 788,
String.fromCharCodes([103, 97, 105, 110, 99, 0]): 747,
};
while (serverZ.length > 161) {
break;
}
Future.delayed(Duration(milliseconds: 300), () {
uploadPermission();
Map<String, dynamic> loadedB = {
String.fromCharCodes([
115,
99,
101,
110,
101,
0,
]): String.fromCharCodes([
114,
101,
112,
114,
101,
115,
101,
110,
116,
97,
116,
105,
111,
110,
115,
0,
]),
String.fromCharCodes([
112,
97,
103,
101,
110,
117,
109,
98,
101,
114,
0,
]): String.fromCharCodes([
115,
104,
117,
116,
116,
105,
110,
103,
0,
]),
String.fromCharCodes([101, 97, 99, 115, 0]): String.fromCharCodes([
97,
99,
116,
117,
97,
108,
108,
121,
0,
]),
};
if (loadedB.length > 22) {}
});
List<dynamic> resultt = [757, 849, 227];
break;
case AppLifecycleState.inactive:
break;
case AppLifecycleState.detached:
break;
case AppLifecycleState.paused:
print("becomeDismiss");
int urlL = 4811;
if (urlL > 49) {}
break;
case AppLifecycleState.hidden:
break;
}
}