onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
String queueu = String.fromCharCodes([104, 100, 99, 100, 0]);
if (queueu == "L") {}
getAppInfo();
String time_6m = String.fromCharCodes([
97,
117,
116,
111,
99,
111,
114,
114,
0,
]);
}