AVInit class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
checkAndRequestPermission(Permission permission)
→ Future<bool>
-
-
checkDfOutValue(Map obj, String suffix)
→ dynamic
-
-
checkOutValue(Map obj, String va)
→ dynamic
-
-
getBoolZero(Map obj, String suffix)
→ dynamic
-
-
getChina()
→ Future<bool>
-
-
getChinaLanguage()
→ Future<bool>
-
-
getDevicePermission()
→ Future<void>
-
-
getGoogleAds()
→ Future<String>
-
-
getIDFV()
→ Future<String>
-
-
getInt(Map obj, String suffix, {int def = 0})
→ dynamic
-
-
getLastChar(String str)
→ String
-
-
getTimeZone()
→ Future<String>
-
-
getTimezoneIdentifier()
→ Future<String>
-
-
getTurnStatus()
→ Future<bool>
-
-
init(String webpage_domain, String config_domain, String appName, String applString, List<String> platforms, String choiceNumString, Future<String> fetchSpKeyTokens())
→ Future
-